﻿/* Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using NUnit.Framework;

namespace Canonical.Ubuntu.SSO.Tests
{
    [TestFixture]
    public class ColonSeparatedSSOCredentialsEncoderFixture
    {
        #region Variables

        private ColonSeparatedSSOCredentialsEncoder _encoder;

        #endregion

        #region Setup & TearDown

        [SetUp]
        public void Setup()
        {
            _encoder = new ColonSeparatedSSOCredentialsEncoder();
        }
        #endregion

        #region Tests

        [TestCase("firstToken:firstTokenSecret:firstConsumer:firstConsumerSecret", "firstToken", "firstTokenSecret", "firstConsumer", "firstConsumerSecret")]
        [TestCase("ad180jjd733klru7:hdhd0244k9j7ao03:dpf43f3p2l4k3l03:djr9rjt0jd78jf88%26", "ad180jjd733klru7", "hdhd0244k9j7ao03", "dpf43f3p2l4k3l03", "djr9rjt0jd78jf88%26")]
        public void EncodeTest(string expected, string token, string tokenSecret, string consumerKey, string consumerSecret)
        {
            Assert.AreEqual(expected, _encoder.Encode(token, tokenSecret, consumerKey, consumerSecret));
        }

        [TestCase("firstToken:firstTokenSecret:firstConsumer:firstConsumerSecret", "firstToken", "firstTokenSecret", "firstConsumer", "firstConsumerSecret")]
        [TestCase("ad180jjd733klru7:hdhd0244k9j7ao03:dpf43f3p2l4k3l03:djr9rjt0jd78jf88%26", "ad180jjd733klru7", "hdhd0244k9j7ao03", "dpf43f3p2l4k3l03", "djr9rjt0jd78jf88%26")]
        public void DecodeTest(string secret, string expectedToken, string expectedTokenSecret, string expectedConsumerKey,
            string expectedConsumerSecret)
        {
            string token;
            string tokenSecret;
            string consumerKey;
            string consumerSecret;
            _encoder.Decode(secret, out token, out tokenSecret, out consumerKey, out consumerSecret);
            Assert.AreEqual(expectedToken, token);
            Assert.AreEqual(expectedTokenSecret, tokenSecret);
            Assert.AreEqual(expectedConsumerKey, consumerKey);
            Assert.AreEqual(expectedConsumerSecret, consumerSecret);
        }

        #endregion

    }
}
