﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of Ubuntu One on Windows.
 * 
 * Ubuntu One on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with Ubuntu One for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using NUnit.Framework;

namespace Canonical.Ubuntu.SSO.Tests
{

    [TestFixture]
    public class CredentialsErrorEventArgsFixture
    {

        #region Variables

        private CredentialsErrorEventArgs _args;
        #endregion

        #region Tests

        [Test]
        public void EmptyConstructorTest()
        {
            _args = new CredentialsErrorEventArgs();
            Assert.AreEqual(string.Empty, _args.ApplicationName);
            Assert.AreEqual(string.Empty, _args.DetailedErrorMessage);
            Assert.AreEqual(string.Empty, _args.ErrorMessage);
        }

        [TestCase("UbuntuOne", "Error 08")]
        [TestCase("Tomboy", "NullReferenceException")]
        [TestCase("OtherApp", "StupidError")]
        public void ApplicationErrorConstructorTest(string appName, string error)
        {
            _args = new CredentialsErrorEventArgs(appName, error);
            Assert.AreEqual(appName, _args.ApplicationName);
            Assert.AreEqual(error, _args.ErrorMessage);
            Assert.AreEqual(string.Empty, _args.DetailedErrorMessage);
        }

        [TestCase("UbuntuOne", "Error 08", "You do not have the keyring rigths.")]
        [TestCase("Tomboy", "NullReferenceException", "Stupid extension")]
        [TestCase("OtherApp", "StupidError", "Learn to code")]
        public void ApplicationErrorDetailConstructorTest(string appName, string error, string detail)
        {
            _args = new CredentialsErrorEventArgs(appName, error, detail);
            Assert.AreEqual(appName, _args.ApplicationName);
            Assert.AreEqual(error, _args.ErrorMessage);
            Assert.AreEqual(detail, _args.DetailedErrorMessage);
        }

        #endregion

    }
}
