﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of Ubuntu One on Windows.
 * 
 * Ubuntu One on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with Ubuntu One for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.Collections;
using System.Collections.Generic;
using NUnit.Framework;

namespace Canonical.Ubuntu.SSO.Tests
{
    [TestFixture]
    public class CredentialsFoundEventArgsFixture
    {
        #region Variables

        private CredentialsFoundEventArgs _args;

        #endregion

        #region Tests

        [Test]
        public void EmptyConstructorTest()
        {
            _args = new CredentialsFoundEventArgs();
            Assert.AreEqual(string.Empty, _args.ApplicationName);
            Assert.IsEmpty((ICollection)_args.Credentials.Values);
        }

        [TestCase("UbuntuOne", "token", "tokenSecret", "consumerKey", "consumerSecret")]
        [TestCase("Tomboy", "tomboyToken", "tomboyToeknSecret", "tomboyConsumerKey", "tomboyConsumerSecret")]
        public void AppNameCredentialsConstructor(string appName, string token, string tokenSecret, 
            string consumerKey, string consumerSecret )
        {
            // create the dict with the data
            var credentials = new Dictionary<string, string>
            {
                {"Token", token},
                {"TokenSecret", tokenSecret},
                {"ConsumerKey", consumerKey},
                {"ConsumerSecret", consumerSecret}
            };
            _args = new CredentialsFoundEventArgs(appName, credentials);
            Assert.AreEqual(appName, _args.ApplicationName);
            Assert.AreSame(credentials, _args.Credentials);
        }

        #endregion
    }
}
