﻿/* Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using Newtonsoft.Json.Linq;
using NUnit.Framework;

namespace Canonical.Ubuntu.SSO.Tests
{
    [TestFixture]
    public class JsonCredentialsEncoderFixture
    {
        #region Variables

        private JsonSSOCredentialsEncoder _encoder;

        #endregion

        #region Setup & TearDown

        [SetUp]
        public void Setup()
        {
            _encoder = new JsonSSOCredentialsEncoder();    
        }

        #endregion

        #region Tests

        [TestCase("token", "tokenSecret", "consumerKey", "consumerSecret")]
        [TestCase("asasferer", "ykvchdclsc", "sdahdlfa", "zcknvculdsnv")]
        public void EncodeTest(string token, string tokenSecret, string consumerKey, string consumerSecret)
        {
            // pass the data to encode, later test that the required data is present
            // and that the data is the same.
            var encodedData = _encoder.Encode(token, tokenSecret, consumerKey, consumerSecret);
            // use the Json.Net to read the result string and ensure we do have the data
            var credentials = JObject.Parse(encodedData);
            Assert.AreEqual(token, (string)credentials["token"]);
            Assert.AreEqual(tokenSecret, (string)credentials["token_secret"]);
            Assert.AreEqual(consumerKey, (string)credentials["consumer_key"]);
            Assert.AreEqual(consumerSecret, (string)credentials["consumer_secret"]);
        }

        [TestCase("token", "tokenSecret", "consumerKey", "consumerSecret")]
        [TestCase("asasferer", "ykvchdclsc", "sdahdlfa", "zcknvculdsnv")]
        public void DecodeTest(string token, string tokenSecret, string consumerKey, string consumerSecret)
        {
            // create the encoded data, decode it an ensure is the same
            string returnedToken;
            string returnedTokenSecret;
            string returnedConsumerKey;
            string returnedConsumerSecret;

            var encodedData = _encoder.Encode(token, tokenSecret, consumerKey, consumerSecret);
            _encoder.Decode(encodedData, out returnedToken, out returnedTokenSecret, 
                out  returnedConsumerKey, out returnedConsumerSecret);
            Assert.AreEqual(token, returnedToken);
            Assert.AreEqual(tokenSecret, returnedTokenSecret);
            Assert.AreEqual(consumerKey, returnedConsumerKey);
            Assert.AreEqual(consumerSecret, returnedConsumerSecret);
        }

        [TestCase(null, "tokenSecret", "consumerKey", "consumerSecret")]
        [TestCase("token", null, "consumerKey", "consumerSecret")]
        [TestCase("token", "tokenSecret", null, "consumerSecret")]
        [TestCase("token", "tokenSecret", "consumerKey", null)]
        [ExpectedException(typeof(SSOException))]
        public void DecodeEmptyDataTest(string token, string tokenSecret, string consumerKey, string consumerSecret)
        {
            // encode the data, then try to decode an expect the exception
            string returnedToken;
            string returnedTokenSecret;
            string returnedConsumerKey;
            string returnedConsumerSecret;

            var encodedData = _encoder.Encode(token, tokenSecret, consumerKey, consumerSecret);
            _encoder.Decode(encodedData, out returnedToken, out returnedTokenSecret,
                out  returnedConsumerKey, out returnedConsumerSecret);
        }

        #endregion

    }
}
