﻿/* Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using Canonical.Ubuntu.SSO.Service;
using Canonical.UbuntuOne.Common.Net;
using NUnit.Framework;
using Rhino.Mocks;

namespace Canonical.Ubuntu.SSO.Tests
{
    [TestFixture]
    public class SSOLoginProcessorFixture
    {
        #region Variables

        private MockRepository _mocks;
        private Authentications _auth;
        private IKeyring _keyring;
        private ISSOCredentialsEncoder _encode;
        private IOAuth _oauth;
        private IHttpWebRequestFactory _requestFactory;
        private IHttpWebRequest _request;
        private SSOLoginProcessor _processor;

        #endregion

        #region Setup

        [SetUp]
        public void Setup()
        {
            _mocks = new MockRepository();
            _auth = _mocks.DynamicMock<Authentications>();
            _keyring = _mocks.DynamicMock<IKeyring>();
            _encode = _mocks.DynamicMock<ISSOCredentialsEncoder>();
            _oauth = _mocks.DynamicMock<IOAuth>();
            _requestFactory = _mocks.DynamicMock<IHttpWebRequestFactory>();
            _request = _mocks.DynamicMock<IHttpWebRequest>();
            _processor = new SSOLoginProcessor
            {
                Authentications = _auth,
                HttpWebRequestFactory = _requestFactory,
                Keyring = _keyring,
                OAuth = _oauth,
                SSOCredentialsEncoder = _encode
            };
        }

        #endregion

        #region Tests

        [TestCase("manuel@canonical.com", "Passwd", "UbuntuOne")]
        [TestCase("mandel@themacaque.com", "Test", "Gwibber")]
        [ExpectedException(typeof(SSOLoginException))]
        public void LoginCredentialsExceptionTest(string email, string password, string tokenName)
        {
            Assert.Ignore("Not yet implemented");
        }

        [Test]
        [ExpectedException(typeof(SSOLoginException))]
        public void LoginPingExceptionTest()
        {
            Assert.Ignore("Not yet implemented");
        }

        [Test]
        public void LoginNoSecretTest()
        {
            Assert.Ignore("Not yet implemented");
        }

        [Test]
        public void LoginSecretTest()
        {
            Assert.Ignore("Not yet implemented");
        }

        #endregion

    }
}
