﻿/* Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
namespace Canonical.Ubuntu.SSO
{
    /// <summary>
    /// Encode implementation that encodes the oauth token using colons as separators.
    /// </summary>
    public class ColonSeparatedSSOCredentialsEncoder : ISSOCredentialsEncoder
    {
        #region Implementation of ISSOCredentialsEncoder

        /// <summary>
        /// Encodes oauth credentials so that they can be stored in a keyring.
        /// </summary>
        /// <param name="token">The oauth token.</param>
        /// <param name="tokenSecret">The oauth secret.</param>
        /// <param name="consumerKey">The oauth consumer key.</param>
        /// <param name="consumerSecret">The oauth consumer secret.</param>
        /// <returns>a stirng that represents the oauth token.</returns>
        public string Encode(string token, string tokenSecret, string consumerKey, string consumerSecret)
        {
            return string.Format("{0}:{1}:{2}:{3}", token, tokenSecret, consumerKey, consumerSecret);
        }

        /// <summary>
        /// Decodes the oauth credentials from a single string.
        /// </summary>
        /// <param name="secret">The secret that was stored in the keyring.</param>
        /// <param name="token">Out var where the ouath token will be returned.</param>
        /// <param name="tokenSecret">Out var where the oauth token secret will be returned.</param>
        /// <param name="consumerKey">Out var where the oauth consumer key will be returned.</param>
        /// <param name="consumerSecret">Out var where the oauth consumer secret will be returned.</param>
        public void Decode(string secret, out string token, out string tokenSecret, out string consumerKey, out string consumerSecret)
        {
            var data = secret.Split(":".ToCharArray(),4);
            token = data[0];
            tokenSecret = data[1];
            consumerKey = data[2];
            consumerSecret = data[3];
        }

        #endregion
    }
}
