﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of Ubuntu One on Windows.
 * 
 * Ubuntu One on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with Ubuntu One for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;

namespace Canonical.Ubuntu.SSO
{
    /// <summary>
    /// Envent argument used to notify that there was an error when retrieving the credentials
    /// for an application.
    /// </summary>
    public class CredentialsErrorEventArgs : EventArgs
    {
        /// <summary>
        /// Gets and sets the name of the application that requested the credentials that
        /// got an error.
        /// </summary>
        public string ApplicationName { get; set; }

        /// <summary>
        /// Gets and sets the message that can be shown to the user explaining the error.
        /// </summary>
        public string ErrorMessage { get; set; }

        /// <summary>
        /// Gets and sets the stack trace with the details of the error.
        /// </summary>
        public string DetailedErrorMessage { get; set; }

        /// <summary>
        /// Creates a new instance of the class with its data init to the base values.
        /// </summary>
        public CredentialsErrorEventArgs()
            : this("",""){
        }

        /// <summary>
        /// Creates a new instance of the class with the passed data.
        /// </summary>
        /// <param name="applicationName">The name of the applications whose credentials were requested.</param>
        /// <param name="errorMessage">An error message that can be shown to the user.</param>
        public CredentialsErrorEventArgs(string applicationName, string errorMessage)
            : this(applicationName, errorMessage, ""){
        }

        /// <summary>
        /// Creates a new instance of the calss with the passed data.
        /// </summary>
        /// <param name="appliactionName">The name of the applications whose credentials were requested.</param>
        /// <param name="errorMessage">An error message that can be shown to the user.</param>
        /// <param name="detailErrorMessage">A stack trace with the details of the error.</param>
        public CredentialsErrorEventArgs(string appliactionName, string errorMessage, string detailErrorMessage)
        {
            ApplicationName = appliactionName;
            ErrorMessage = errorMessage;
            DetailedErrorMessage = detailErrorMessage;
        }
    }
}
