﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of Ubuntu One on Windows.
 * 
 * Ubuntu One on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with Ubuntu One for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.Collections.Generic;

namespace Canonical.Ubuntu.SSO
{
    /// <summary>
    /// Event argsuments that are used to notify that the credentials of an 
    /// application where correctly retrieved.
    /// </summary>
    public class CredentialsFoundEventArgs : EventArgs
    {
        /// <summary>
        /// Gets and sets the name of the application whose credentials were
        /// found.
        /// </summary>
        public string ApplicationName { get; set; }

        /// <summary>
        /// Gets and set the dictionary that contains at least four keys with 
        /// the token and consumer keys and secrets. The keys are named "consumer_key", 
        /// "consumer_secret", "token" and "token_secret".
        /// </summary>
        public IDictionary<string, string> Credentials { get; set; }

        /// <summary>
        /// Creates a new instance of the class with its data init to the 
        /// basic values.
        /// </summary>
        public CredentialsFoundEventArgs()
            : this("", new Dictionary<string, string>()){
        }

        /// <summary>
        /// Creates a new isntance of the class with the given data.
        /// </summary>
        /// <param name="applicationName">The name of the application whose credentials 
        /// were found.</param>
        /// <param name="credentials">The credentials of the application.</param>
        public CredentialsFoundEventArgs(string applicationName, 
            IDictionary<string, string> credentials)
        {
            ApplicationName = applicationName;
            Credentials = credentials;
        }
    }
}
