﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.Security.Cryptography;

namespace Canonical.Ubuntu.SSO
{
    /// <summary>
    /// Interface to be implemented by those objects that are able to encryp and decrypt users
    /// data to protect it.
    /// </summary>
    public interface IDataProtector
    {
        /// <summary>
        /// Protects the userData parameter and returns a string.
        /// </summary>
        /// <param name="userData">A string containing data to protect. </param>
        /// <param name="optionalEntropy">An additional byte array used to encrypt the data. </param>
        /// <param name="scope">One of the DataProtectionScope values.</param>
        /// <returns>A byte[] representing the encrypted data.</returns>
        byte[] Protect(string userData, byte[] optionalEntropy, DataProtectionScope scope);

        /// <summary>
        /// Unprotects the encryptedData parameter and returns a string.
        /// </summary>
        /// <param name="encryptedData">A string containing data encrypted using the Protect method.</param>
        /// <param name="optionalEntropy">An additional byte array used to encrypt the data.</param>
        /// <param name="scope">One of the DataProtectionScope values. </param>
        /// <returns>A string representing the unprotected data.</returns>
        string Unprotect(byte[] encryptedData, byte[] optionalEntropy, DataProtectionScope scope);
    }
}
