﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of Ubuntu One on Windows.
 * 
 * Ubuntu One on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with Ubuntu One for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.Collections.Generic;

namespace Canonical.Ubuntu.SSO
{
    /// <summary>
    /// Interface to be implemented by a class that allows to store data in the registry of the 
    /// current user and makes the class behave like a keyring.
    /// </summary>
    public interface IKeyring : IDisposable
    {
        /// <summary>
        /// Creates a new secret in the the keyring with the given name for a given applciation.
        /// </summary>
        /// <param name="keyringName">The name of the keyring where the secret will be stored.</param>
        /// <param name="applicationName">The name of the application whose secret will be stored.</param>
        /// <param name="secret">The secret to store in the keyring.</param>
        void CreateSecret(string keyringName, string applicationName, string secret);

        /// <summary>
        /// Gets the secret froma keyring using the name of the application that stored it.
        /// </summary>
        /// <param name="keyringName">The name of the keyring where the secret was stored.</param>
        /// <param name="applicationName">the name of the application that stored the secret.</param>
        /// <returns>An empty string if the secret does not exist, the secret otherwhise.</returns>
        string GetSecretByName(string keyringName, string applicationName);

        /// <summary>
        /// Gets a lists with all the names of the available ekyrings.
        /// </summary>
        /// <returns>An enumerable with all the names of the different keyrings.</returns>
        IEnumerable<string> GetKeyrings();

        /// <summary>
        /// Gets a list with all the applications in a keyring.
        /// </summary>
        /// <param name="keyringName">The name of the keyring that is queried.</param>
        /// <returns>An enumerable with all the applications in the keyring.</returns>
        IEnumerable<string> GetApplications(string keyringName);
    }
}
