﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of Ubuntu One on Windows.
 * 
 * Ubuntu One on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with Ubuntu One for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;

namespace Canonical.Ubuntu.SSO
{
    /// <summary>
    /// Provides the interface to be implemented by a class that will provided a way
    /// to retrieve the credentials of the user using the Ubuntu SSO webservice.
    /// </summary>
    public interface ISSOCredentialsProvider
    {
        #region Events

        /// <summary>
        /// Event raised when the credentials for an application were found.
        /// </summary>
        event EventHandler<CredentialsFoundEventArgs> OnCredentialsFound;

        /// <summary>
        /// Event raised when the credetials from an application were denied.
        /// </summary>
        event EventHandler<CredentialsDeniedEventArgs> OnCredetialsDenied;

        /// <summary>
        /// Event raised when there was an error when retireving the credentials.
        /// </summary>
        event EventHandler<CredentialsErrorEventArgs> OnCredentialsError;

        #endregion

        #region Methods

        /// <summary>
        /// This method will try to fetch the encrypted credentials from the registry and 
        /// return them, and if the credentials are not found it will open a 
        /// dialog letting the user just log into an existing account via the 
        /// Ubuntu SSO webservice, and will then get the related credentials, 
        /// store them into the keyring for future usage and finally return them.
        /// 
        /// The result of this action will be notified through the use of the event handlers
        /// due to the fact that the call to the sso webservice is async.
        /// </summary>
        void LoginToGetCredentials(string eventName, string applicationName);

        /// <summary>
        /// This method will try to fetch the credentials from the registry and return them, 
        /// and if the credentials are not found it will open a dialog letting the user 
        /// either register a new or log into an existing account via the Ubuntu SSO webservice, 
        /// and will then get the related credentials, store them into the registry for future 
        /// usage and finally return them.
        /// 
        /// The result of this action will be notified through the use of the event handlers
        /// due to the fact that the call to the sso webservice is async.
        /// </summary>
        void LoginOrRegisterToGetCredentials();

        #endregion

    }
}
