﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of Ubuntu One on Windows.
 * 
 * Ubuntu One on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with Ubuntu One for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
namespace Canonical.Ubuntu.SSO
{
    /// <summary>
    /// Interface to be implemented by those objects that will provide 
    /// the login an register basic capabilities.
    /// </summary>
    public interface ISSOLoginProcessor
    {
        /// <summary>
        /// Gets and sets the credential encoder that will be used to encode the oauth credentials 
        /// before they are saved in the keyring.
        /// </summary>
        ISSOCredentialsEncoder SSOCredentialsEncoder { get; set; }

        /// <summary>
        /// Generates a new captha and stores it in the passed file path.
        /// </summary>
        /// <param name="filePath">The path in which the captcha should be stored.</param>
        /// <returns></returns>
        string GenerateCaptcha(string filePath);

        /// <summary>
        /// Registers a new user to the system.
        /// </summary>
        /// <param name="email">The email of the new user to register.</param>
        /// <param name="password">The password that the new user will use to login.</param>
        /// <param name="captchaId">The id of the captcha that the user used to register.</param>
        /// <param name="captchaSolution">The solution given by the user for the given captcha</param>
        /// <returns>The email of the new user if there were no login issues.</returns>
        string RegisterUser(string email, string password, string captchaId, string captchaSolution);

        /// <summary>
        /// Allows a user to login using the ubuntu sso.
        /// </summary>
        /// <param name="email">The email of the user.</param>
        /// <param name="password">The password to be used for login.</param>
        /// <param name="tokenName">The token name used for login.</param>
        /// <returns>A string with the sso credentials.</returns>
        string Login(string email, string password, string tokenName);

        /// <summary>
        /// Validate an email token for a user.
        /// </summary>
        /// <param name="email">The email address of the user.</param>
        /// <param name="password">The apssword of the user.</param>
        /// <param name="emailToken">Teh email token to validate.</param>
        /// <param name="tokenName">The name of the token to validate.</param>
        /// <returns>The token returned by the server.</returns>
        string ValidateEmail(string email, string password, string emailToken, string tokenName);

        /// <summary>
        /// Allwos to request a password reset.
        /// </summary>
        /// <param name="email">The email of the user requesting the password reset.</param>
        void RequestPasswordResetToken(string email);

        /// <summary>
        /// Set a new password for the account.
        /// <remarks>
        /// The 'token' has to be the one resulting from a call to 'RequestPasswordResetToken'.
        /// </remarks>
        /// </summary>
        /// <param name="email">The email of the user.</param>
        /// <param name="token">The token received from requesting the password reset.</param>
        /// <param name="newPassword">The new password to be used by the account.</param>
        /// <returns>The email of the account if everyhing went ok.</returns>
        string SetNewPassword(string email, string token, string newPassword);
    }
}
