﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.Collections.Generic;
using System.IO;
using System.Net;
using System.Text;

namespace Canonical.Ubuntu.SSO.Service
{
    public partial class Authentications
    {
        private class AuthenticationsCustomizer : ICustomize
        {
            #region Implementation of ICustomize

            public T Parse<T>(string rawString)
            {
                throw new NotImplementedException();
            }

            public string Fetch(HttpMethodType methodType, string uri, Dictionary<string, string> httpHeadersParam, string dataParam)
            {
                var fetchedData = string.Empty;

                string uriData = string.Format("{0}/authentications", uri);
                switch (methodType)
                {

                    case HttpMethodType.GET:
                        uriData = uriData + string.Format("?{0}", dataParam);
                        var getRequest = (HttpWebRequest)WebRequest.Create(uriData);
                        getRequest.Method = "GET";
                        getRequest.ContentType = "application/x-www-form-urlencoded";
                        getRequest.Accept = "application/json";
                        var getResponse = (HttpWebResponse)getRequest.GetResponse();
                        var getResponseReader = new StreamReader(getResponse.GetResponseStream());
                        fetchedData = getResponseReader.ReadToEnd();
                        break;


                    case HttpMethodType.POST:
                        var request = (HttpWebRequest)WebRequest.Create(uriData);
                        request.Method = "POST";
                        request.ContentType = "application/x-www-form-urlencoded";
                        request.Accept = "application/json";
                        using (var stream = request.GetRequestStream())
                        {
                            var data = Encoding.ASCII.GetBytes(dataParam);
                            stream.Write(data, 0, data.Length);
                            stream.Close();
                        }

                        var response = (HttpWebResponse)request.GetResponse();
                        var responseReader = new StreamReader(response.GetResponseStream());
                        var responseData = responseReader.ReadToEnd();

                        break;

                    case HttpMethodType.PUT:
                        break;

                    case HttpMethodType.PATCH:
                        break;

                    case HttpMethodType.DELETE:
                        break;

                }


                return fetchedData;
            }

            public string Fetch(string username, string password, HttpMethodType methodType, string uri, Dictionary<string, string> httpHeadersParam, string dataParam)
            {
                var fetchedData = string.Empty;

                string uriData = string.Format("{0}/authentications", uri);
                switch (methodType)
                {

                    case HttpMethodType.GET:
                        uriData = uriData + string.Format("?{0}", dataParam);
                        var getRequest = (HttpWebRequest)WebRequest.Create(uriData);
                        getRequest.Method = "GET";
                        getRequest.ContentType = "application/x-www-form-urlencoded";
                        getRequest.Accept = "application/json";
                        getRequest.Headers.Add("Authorization", "Basic " +
                            Convert.ToBase64String(
                            Encoding.ASCII.GetBytes(string.Format("{0}:{1}", username, password))));
                        var getResponse = (HttpWebResponse)getRequest.GetResponse();
                        var getResponseReader = new StreamReader(getResponse.GetResponseStream());
                        fetchedData = getResponseReader.ReadToEnd();
                        break;


                    case HttpMethodType.POST:
                        var request = (HttpWebRequest)WebRequest.Create(uriData);
                        request.Method = "POST";
                        request.ContentType = "application/x-www-form-urlencoded";
                        request.Accept = "application/json";
                        using (var stream = request.GetRequestStream())
                        {
                            var data = Encoding.ASCII.GetBytes(dataParam);
                            stream.Write(data, 0, data.Length);
                            stream.Close();
                        }

                        var response = (HttpWebResponse)request.GetResponse();
                        var responseReader = new StreamReader(response.GetResponseStream());
                        var responseData = responseReader.ReadToEnd();

                        break;

                    case HttpMethodType.PUT:
                        break;

                    case HttpMethodType.PATCH:
                        break;

                    case HttpMethodType.DELETE:
                        break;

                }


                return fetchedData;
            }

            public string Serialize(HttpMethodType methodType, Dictionary<string, string> keyvalues)
            {
                string serializedString = string.Empty;


                switch (methodType)
                {

                    case HttpMethodType.GET:

                    case HttpMethodType.POST:

                        serializedString = CreateUrlString(keyvalues);

                        break;


                    case HttpMethodType.PATCH:

                    case HttpMethodType.PUT:

                        serializedString = CreateJsonString(keyvalues);

                        break;

                }


                return serializedString;
            }

            private static string CreateUrlString(Dictionary<string, string> keyvalues)
            {

                List<string> keyValue = new List<string>();


                foreach (KeyValuePair<string, string> pair in keyvalues)
                {

                    string pairedData = string.Format("{0}={1}", pair.Key, pair.Value);

                    keyValue.Add(pairedData);

                }


                return string.Join("&", keyValue.ToArray());

            }


            private static string CreateJsonString(Dictionary<string, string> keyvalues)
            {

                List<string> keyValue = new List<string>();


                foreach (KeyValuePair<string, string> pair in keyvalues)
                {

                    string pairedData = string.Format("\"{0}\":\"{1}\"", pair.Key, pair.Value);

                    keyValue.Add(pairedData);

                }


                string jsonBody = string.Join(",", keyValue.ToArray());


                return "{" + jsonBody + "}";

            }

            #endregion
        }

        /// <summary>
        /// Basic constructor that will init the data of the object to be used with the Ubuntu SSO servers
        /// </summary>
        public Authentications()
            : this(Constants.ServiceUrl, new Dictionary<string, string>(), new AuthenticationsCustomizer())
        {

        }
    }
}
