﻿/* Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.Collections.Generic;
using System.Threading;
using Avalon.Windows.Controls;
using Canonical.UbuntuOne.Client.Notification;
using Canonical.UbuntuOne.Common.Threading;

namespace Canonical.UbuntuOne.Client.Views
{
    /// <summary>
    /// Interaction logic for UbuntuOneNotifyIcon.xaml
    /// </summary>
    public partial class UbuntuOneNotifyIcon : INotificationIconView
    {
        #region Variables

        private IDispatcher _dispatcher;
        private readonly object _dispatcherLock = new object();

        #endregion

        #region DI Properties

        /// <summary>
        /// Gets and sets the presenter that contains the logic that is used by the notification icon.
        /// </summary>
        public INotificationIconPresenter NotificationIconPresenter { get; set; }

        #endregion

        /// <summary>
        /// Initializes a new instance of the UbuntuOneNotifyIcon class.
        /// </summary>
        public UbuntuOneNotifyIcon()
        {
            InitializeComponent();
        }

        #region Implementation of INotificationIconView

        public bool IsManualSyncEnabled
        {
            get { return UbuntuOneManualSync.IsEnabled; }
            set { UbuntuOneManualSync.IsEnabled = value; }
        }

        /// <summary>
        /// Shows the given notification to the user.
        /// </summary>
        /// <param name="timeout">The amount of time to show the notification.</param>
        /// <param name="title">The title of the notification.</param>
        /// <param name="text">The text of the notification.</param>
        public void ShowNotification(int timeout, string title, string text)
        {
            NotifyIcon.ShowBalloonTip(timeout, title, text, NotifyBalloonIcon.Info);
        }

        /// <summary>
        /// Gets and sets the list of recently modified files.
        /// </summary>
        public IList<string> RecentlyModifiedFiles
        {
            get { throw new NotImplementedException(); }
            set { throw new NotImplementedException(); }
        }

        /// <summary>
        /// Gets and sets the state od the sync daemon to be displayed.
        /// </summary>
        public string State
        {
            get { return (string)StateMenuItem.Header; }
            set { StateMenuItem.Header = value; }
        }

        /// <summary>
        /// Gets and sets the string with the information of the current operation being
        /// performed.
        /// </summary>
        public string CurrentOperation
        {
            get { throw new NotImplementedException(); }
            set { throw new NotImplementedException(); }
        }

        /// <summary>
        /// Gets the dispatcher that can be used to call actions on the object from a 
        /// different thread.
        /// </summary>
        public IDispatcher ViewDispatcher
        {
            get
            {
                if(_dispatcher == null)
                {
                    lock (_dispatcherLock)
                    {
                        _dispatcher = new WpfDispatcher(Dispatcher);
                    }
                }
                return _dispatcher;
            }
            set { _dispatcher = value; }
        }
        #endregion

        private void OnUbuntuOneManualSyncClick(object sender, System.Windows.RoutedEventArgs e)
        {
            var thread = new Thread(NotificationIconPresenter.ManualSync);
            thread.Start();
        }

        private void OnExitMenuItemClick(object sender, System.Windows.RoutedEventArgs e)
        {
            NotificationIconPresenter.Exit();
        }

        private void OnHelpMenuItemClick(object sender, System.Windows.RoutedEventArgs e)
        {
            NotificationIconPresenter.OpenHelp();
        }

        private void OnMoreSpaceMenuItemClick(object sender, System.Windows.RoutedEventArgs e)
        {
            NotificationIconPresenter.OpenUpgradeOption();
        }

        private void OnOpenShareManueItemClick(object sender, System.Windows.RoutedEventArgs e)
        {
            NotificationIconPresenter.OpenSyncsLocation();
        }

        private void OnUbuntuOnePreferencesMenuItemClick(object sender, System.Windows.RoutedEventArgs e)
        {
            NotificationIconPresenter.OpenUbuntuOnePreferences();
        }

    }
}
