﻿/* Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.Windows;
using Canonical.UbuntuOne.Client.Preferences;

namespace Canonical.UbuntuOne.Client.Views
{
    /// <summary>
    /// Interaction logic for PreferencesDialog.xaml
    /// </summary>
    public partial class PreferencesDialog : Window, IPreferencesView
    {
        #region DI properties

        /// <summary>
        /// Gets and sets the presenter that will be used by the view.
        /// </summary>
        public IPreferencesDialogPresenter PreferencesDialogPresenter { get; set; }

        #endregion

        /// <summary>
        /// Initializes a new instance of the PreferencesDialog class.
        /// </summary>
        public PreferencesDialog()
        {
            InitializeComponent();
        }

        public string UserName
        {
            set { AccountsTab.UserName = value; }
        }

        public string Email
        {
            set { AccountsTab.Email = value; }
        }

        public string CurrentPlan
        {
            set { AccountsTab.CurrentPlan = value; }
        }

        public bool IsBookmarksSynced
        {
            get { return ServicesTab.IsBookmarksSynced; }
            set { ServicesTab.IsBookmarksSynced = value; }
        }

        public bool IsBroadcastSynced
        {
            get { return ServicesTab.IsBroadcastSynced; }
            set { ServicesTab.IsBroadcastSynced = value; }
        }

        public bool IsContactsSynced
        {
            get { return ServicesTab.IsContactsSynced; }
            set { ServicesTab.IsContactsSynced = value; }
        }

        public bool IsFilesSynced
        {
            get { return ServicesTab.IsFilesSynced; }
            set { ServicesTab.IsFilesSynced = value; }
        }

        public bool IsMusicSynced
        {
            get { return ServicesTab.IsMusicSynced; }
            set { ServicesTab.IsMusicSynced = value; }
        }

        public bool IsAutoSyncEnable
        {
            get { return WindowsTab.IsAutoSyncEnable; }
            set { WindowsTab.IsAutoSyncEnable = value; }
        }

        public double AutoSyncFrequency
        {
            get { return WindowsTab.AutoSyncFrequency; }
            set { WindowsTab.AutoSyncFrequency = value; }
        }

        void IPreferencesView.ShowDialog()
        {
            ShowDialog();
        }

        private void OnCloseButtonClick(object sender, RoutedEventArgs e)
        {
            Hide(); 
            // tell the presenter we are closing and that he needs to update the preferences
            PreferencesDialogPresenter.UpdatePreferences();
        }
    }
}
