﻿// Copyright 2010 Canonical Ltd.
// 
// This file is part of UbuntuOne on Windows.
// 
// UbuntuOne on Windows is free software: you can redistribute it and/or modify		
// it under the terms of the GNU Lesser General Public License version 		
// as published by the Free Software Foundation.		
//		
// Ubuntu One on Windows is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
// GNU Lesser General Public License for more details.	
//
// You should have received a copy of the GNU Lesser General Public License	
// along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
// 
// Authors: Manuel de la Peña <manuel.delapena@canonical.com>
using System.Windows;
using Canonical.UbuntuOne.Common;

namespace Canonical.UbuntuOne.Client.Views
{
    /// <summary>
    /// Provides a collection of useful method to show information to the user.
    /// </summary>
    public class UbuntuOneMessageBox : IMessageBox
    {
        /// <summary>
        /// Displays an error dialog with a given message.
        /// </summary>
        /// <param name="message">The message to be displayed.</param>
        public void ShowError(string message)
        {
            ShowMessage(message, MessageBoxImage.Error);
        }

        /// <summary>
        /// Displays an error dialog with a given message.
        /// </summary>
        /// <param name="message">The message to be displayed.</param>
        public void ShowInformation(string message)
        {
            ShowMessage(message, MessageBoxImage.Information);
        }

        /// <summary>
        /// Displays an error dialog with a given message.
        /// </summary>
        /// <param name="message">The message to be displayed.</param>
        public void ShowWarning(string message)
        {
            ShowMessage(message, MessageBoxImage.Warning);
        }

        /// <summary>
        /// Displays an error dialog with a given message and icon.
        /// </summary>
        /// <param name="message">The message to be displayed.</param>
        /// <param name="icon">The icon to be displayed with the message.</param>
        public void ShowMessage(string message, MessageBoxImage icon)
        {
            MessageBox.Show(message, Resources.Resources.ApplicationName, MessageBoxButton.OK, icon);
        }

        /// <summary>
        /// Displays an OK / Cancel dialog and returns the user input.
        /// </summary>
        /// <param name="message">The message to be displayed.</param>
        /// <param name="icon">The icon to be displayed.</param>
        /// <returns>User selection.</returns>
        public MessageBoxResult ShowOkCancel(string message, MessageBoxImage icon)
        {
            return MessageBox.Show(message, Resources.Resources.ApplicationName, MessageBoxButton.OKCancel, icon);
        }

        /// <summary>
        /// Displays a Yes/No dialog and returns the user input.
        /// </summary>
        /// <param name="message">The message to be displayed.</param>
        /// <param name="icon">The icon to be displayed.</param>
        /// <returns>User selection.</returns>
        public MessageBoxResult ShowYesNo(string message, MessageBoxImage icon)
        {
            return MessageBox.Show(message, Resources.Resources.ApplicationName, MessageBoxButton.YesNo, icon);
        }

        /// <summary>
        /// Displays an Yes / No / Cancel dialog and returns the user input.
        /// </summary>
        /// <param name="message">The message to be displayed.</param>
        /// <param name="icon">The icon to be displayed.</param>
        /// <returns>User selection.</returns>
        public MessageBoxResult ShowYesNoCancel(string message, MessageBoxImage icon)
        {
            return MessageBox.Show(message, Resources.Resources.ApplicationName, MessageBoxButton.YesNoCancel, icon);
        }
    }
}
