﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using Canonical.UbuntuOne.Common.Threading;
using Canonical.UbuntuOne.Common.Update;
using StaticResources = Canonical.UbuntuOne.Client.Views.Resources.Resources;
namespace Canonical.UbuntuOne.Client.Views.Update
{
    /// <summary>
    /// Interaction logic for DownloadingView.xaml
    /// </summary>
    public partial class DownloadingView : IDownloadingView
    {
        #region Variables

        private IDispatcher _dispatcher;
        private readonly object _dispatcherLock = new object();

        #endregion

        /// <summary>
        /// Initializes a new instance of the DownloadingView class.
        /// </summary>
        public DownloadingView()
        {
            InitializeComponent();
            Title = StaticResources.DownloadingDialogTitle;
        }

        /// <summary>
        /// Gets the dispatcher that can be used to call actions on the object from a 
        /// different thread.
        /// </summary>
        public IDispatcher ViewDispatcher
        {
            get
            {
                if(_dispatcher == null)
                {
                    lock (_dispatcherLock)
                    {
                        _dispatcher = new WpfDispatcher(Dispatcher);
                    }
                }
                return _dispatcher;
            }
            set { _dispatcher = value; }
        }

        /// <summary>
        /// Gets and sets if the close button is enabled.
        /// </summary>
        public bool CloseButtonIsEnabled
        {
            get { return CloseButton.IsEnabled; }
            set { CloseButton.IsEnabled = value; }
        }

        /// <summary>
        /// Gets if the view is visible.
        /// </summary>
        public bool IsShown
        {
            get { return IsVisible; }
        }

        /// <summary>
        /// Gets and sets the downloading message to be displayed.
        /// </summary>
        public string DownloadingMessage
        {
            get { return (String)MessageLabel.Content; }
            set { MessageLabel.Content = value; }
        }

        /// <summary>
        /// Gets and sets the min value of the progress.
        /// </summary>
        public double MinimumValue
        {
            get { return Progressbar.Minimum; }
            set { Progressbar.Minimum = value; }
        }

        /// <summary>
        /// Get and sets the max value of the progress.
        /// </summary>
        public double MaximumValue
        {
            get { return Progressbar.Maximum; }
            set { Progressbar.Maximum = value; }
        }

        /// <summary>
        /// Gets and sets the current progress.
        /// </summary>
        public double Progress
        {
            get { return Progressbar.Value; }
            set { Progressbar.Value = value; }
        }

    }
}
