﻿// Copyright 2010 Canonical Ltd.
// 
// This file is part of UbuntuOne on Windows.
// 
// UbuntuOne on Windows is free software: you can redistribute it and/or modify		
// it under the terms of the GNU Lesser General Public License version 		
// as published by the Free Software Foundation.		
//		
// Ubuntu One on Windows is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
// GNU Lesser General Public License for more details.	
//
// You should have received a copy of the GNU Lesser General Public License	
// along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
// 
// Authors: Manuel de la Peña <manuel.delapena@canonical.com>
using System;
using Canonical.UbuntuOne.Common.Threading;
using Canonical.UbuntuOne.Common.Update;

namespace Canonical.UbuntuOne.Client.Views.Update
{
    /// <summary>
    /// Interaction logic for UpdatingView.xaml
    /// </summary>
    public partial class UpdatingView : IUpdatingView
    {
        #region Variables

        private IDispatcher _dispatcher;
        private readonly object _dispatcherLock = new object();

        #endregion

        #region DI Properties

        /// <summary>
        /// Gets and sets a dispatcher that can be used by the view in a multithreaded env.
        /// </summary>
        public IDispatcher ViewDispatcher
        {
            get
            {
               if(_dispatcher == null)
               {
                   lock (_dispatcherLock)
                   {
                       _dispatcher = new WpfDispatcher(Dispatcher);
                   }
               }
                return _dispatcher;
            }
            set { _dispatcher = value; }
        }

        #endregion

        /// <summary>
        /// Initializes a new instance of the UpdatingView class.
        /// </summary>
        public UpdatingView()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Gets and sets if the view is visible
        /// </summary>
        public bool IsShown
        {
            get { return IsVisible; }
        }

        /// <summary>
        /// Gets and sets if the application is being updated.
        /// </summary>
        public bool IsUpdating { get; set; }

        /// <summary>
        /// Gets and sets the text tht tell the user the app is being updated.
        /// </summary>
        public string UpdatingText
        {
            get { return (String)MessageLabel.Content; }
            set { MessageLabel.Content = value; }
        }
    }
}
