﻿// Copyright 2010 Canonical Ltd.
// 
// This file is part of UbuntuOne on Windows.
// 
// UbuntuOne on Windows is free software: you can redistribute it and/or modify		
// it under the terms of the GNU Lesser General Public License version 		
// as published by the Free Software Foundation.		
//		
// Ubuntu One on Windows is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
// GNU Lesser General Public License for more details.	
//
// You should have received a copy of the GNU Lesser General Public License	
// along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
// 
// Authors: Manuel de la Peña <manuel.delapena@canonical.com>
using System.Collections.Generic;
using Canonical.UbuntuOne.Common.Threading;

namespace Canonical.UbuntuOne.Client.Notification
{
    /// <summary>
    /// View that represents a notification interface that will be shown in the systray of the desktop.
    /// </summary>
    public interface INotificationIconView
    {
        /// <summary>
        /// Gets and sets if the manual sync is enabled.
        /// </summary>
        bool IsManualSyncEnabled { get; set; }

        /// <summary>
        /// Shows a notification to the user.
        /// </summary>
        /// <param name="timeout">The amount of time the notification will be shown.</param>
        /// <param name="title">The title of the notification.</param>
        /// <param name="text">The text of the actual notification.</param>
        void ShowNotification(int timeout, string title, string text);

        /// <summary>
        /// Gets and sets the list of recently modified files.
        /// </summary>
        IList<string> RecentlyModifiedFiles { get; set; }

        /// <summary>
        /// Gets and sets the state od the sync daemon to be displayed.
        /// </summary>
        string State { get; set; }

        /// <summary>
        /// Gets and sets the string with the information of the current operation being
        /// performed.
        /// </summary>
        string CurrentOperation { get; set; }

        /// <summary>
        /// Gets the dispatcher that can be used to call actions on the object from a 
        /// different thread.
        /// </summary>
        IDispatcher ViewDispatcher { get; set; }
    }
}
