﻿// Copyright 2010 Canonical Ltd.
// 
// This file is part of UbuntuOne on Windows.
// 
// UbuntuOne on Windows is free software: you can redistribute it and/or modify		
// it under the terms of the GNU Lesser General Public License version 		
// as published by the Free Software Foundation.		
//		
// Ubuntu One on Windows is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
// GNU Lesser General Public License for more details.	
//
// You should have received a copy of the GNU Lesser General Public License	
// along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
// 
// Authors: Manuel de la Peña <manuel.delapena@canonical.com>
using System;

namespace Canonical.UbuntuOne.Client.Notification
{
    /// <summary>
    /// Interface to be implemented by a sync daemon client that will contain the required events that will be used to notify the
    /// NotificationIconPresenter about the different operations that have occurred in the sync daemon client.
    /// </summary>
    public interface ISyncDaemonClientNotifier
    {
        /// <summary>
        /// Event raised when there are notifications to be provided to the notification icon.
        /// </summary>
        event EventHandler<NotificationEventArgs> OnNotification;

        /// <summary>
        /// Event raised when there are changes in the completness of the current opertaion.
        /// </summary>
        event EventHandler<OperationCompletenessEventArgs> OnOperationCompletness;

        /// <summary>
        /// Event raised when there are changed in teh recetly modififed items.
        /// </summary>
        event EventHandler<RecentlyModifiedEventArgs> OnRecentlyModifiedChanged;

        /// <summary>
        /// Event raised when there are changes in the state.
        /// </summary>
        event EventHandler<StateEventArgs> OnStateChanged;
    }
}
