﻿// Copyright 2010 Canonical Ltd.
// 
// This file is part of UbuntuOne on Windows.
// 
// UbuntuOne on Windows is free software: you can redistribute it and/or modify		
// it under the terms of the GNU Lesser General Public License version 		
// as published by the Free Software Foundation.		
//		
// Ubuntu One on Windows is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
// GNU Lesser General Public License for more details.	
//
// You should have received a copy of the GNU Lesser General Public License	
// along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
// 
// Authors: Manuel de la Peña <manuel.delapena@canonical.com>
using System;

namespace Canonical.UbuntuOne.Client.Notification
{
    /// <summary>
    /// Event used to notify the current state of the current operation.
    /// </summary>
    public class OperationCompletenessEventArgs : EventArgs
    {
        /// <summary>
        /// Enumerator that contains the different units used for the downloads.
        /// </summary>
        public enum SpeedUnitsEnum
        {
            /// <summary>
            /// MB per second.
            /// </summary>
            MB,
            /// <summary>
            /// KB per second.
            /// </summary>
            KB,
        }

        /// <summary>
        /// The percentage of the operation that has been done.
        /// </summary>
        public int Percentage { get; set; }

        /// <summary>
        /// The speed in which the operation is being done.
        /// </summary>
        public double Speed { get; set; }

        /// <summary>
        /// The unit used in the speed.
        /// </summary>
        public SpeedUnitsEnum SpeedUnits { get; set; }

        /// <summary>
        /// A string with the operation that is being performed.
        /// </summary>
        public string Operation { get; set; }

        /// <summary>
        /// Creates a new event arge with all its data init to the default values.
        /// </summary>
        public OperationCompletenessEventArgs()
            : this("", 0, 0, SpeedUnitsEnum.MB)
        {
            
        }

        /// <summary>
        /// Creates a new event arg that can be used to state the current completness of an operation.
        /// </summary>
        /// <param name="operation">A string with the operation that is being performed.</param>
        /// <param name="percentage">The percentage of the operation that has been done.</param>
        /// <param name="speed">The speed in which the operation is done.</param>
        /// <param name="units">The units used in the speed.</param>
        public OperationCompletenessEventArgs(string operation, int percentage, double  speed, SpeedUnitsEnum units)
        {
            Operation = operation;
            Percentage = percentage;
            Speed = speed;
            SpeedUnits = units;
        }
    }
}
