﻿// Copyright 2010 Canonical Ltd.
// 
// This file is part of UbuntuOne on Windows.
// 
// UbuntuOne on Windows is free software: you can redistribute it and/or modify		
// it under the terms of the GNU Lesser General Public License version 		
// as published by the Free Software Foundation.		
//		
// Ubuntu One on Windows is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
// GNU Lesser General Public License for more details.	
//
// You should have received a copy of the GNU Lesser General Public License	
// along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
// 
// Authors: Manuel de la Peña <manuel.delapena@canonical.com>
using System;

namespace Canonical.UbuntuOne.Client.Notification
{
    /// <summary>
    /// Event args used to notify about the current operation.
    /// </summary>
    public class StateEventArgs : EventArgs
    {
        /// <summary>
        /// Enumerator that allows to determine the current state of the daemon.
        /// </summary>
        public enum StateEnum
        {
            /// <summary>
            /// The sync daemon is out of sync.
            /// </summary>
            OUT_OF_SYNC,
            /// <summary>
            /// The synd daemong is syncing.
            /// </summary>
            SYNC_IN_PROGRESS,
            /// <summary>
            /// All the files are up to date.
            /// </summary>
            UP_TO_DATE,
            /// <summary>
            /// The sync daemong is in an error state.
            /// </summary>
            ERROR
        }

        /// <summary>
        /// Gets and sets the state given by the event.
        /// </summary>
        public StateEnum State { get; set; }

        /// <summary>
        /// Creates a new state that in init to indicate that the state is up to date
        /// </summary>
        public StateEventArgs()
            : this(StateEnum.UP_TO_DATE)
        {
        }

        /// <summary>
        /// Creates a new event arg with the given state.
        /// </summary>
        /// <param name="state">The state to be givn by the event.</param>
        public StateEventArgs(StateEnum state)
        {
            State = state;
        }
    }
}
