﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
namespace Canonical.UbuntuOne.Client.Preferences
{
    /// <summary>
    /// Interface to be implemented by those UI components that are used to display the Ubuntu One
    /// preferences.
    /// </summary>
    public interface IPreferencesView
    {
        /// <summary>
        /// Allows to set the name that will be displayed in the UI.
        /// </summary>
        string UserName { set; }

        /// <summary>
        /// Allows to set the users email in the UI.
        /// </summary>
        string Email { set; }

        /// <summary>
        /// Allows to set the current plan of the user.
        /// </summary>
        string CurrentPlan { set; }

        /// <summary>
        /// Allows to get and set if the bookmarks are synced.
        /// </summary>
        bool IsBookmarksSynced { get; set; }

        /// <summary>
        /// Allows to get or set if the broadcast is synced.
        /// </summary>
        bool IsBroadcastSynced { get; set; }

        /// <summary>
        /// Allows to get and set if the contacts are synced.
        /// </summary>
        bool IsContactsSynced { get; set; }

        /// <summary>
        /// Allows to get and set if the files re synced.
        /// </summary>
        bool IsFilesSynced { get; set; }

        /// <summary>
        /// Allows to get and set if the music is synced.
        /// </summary>
        bool IsMusicSynced { get; set; }

        /// <summary>
        /// Allows to get and set if the autosync does occur.
        /// </summary>
        bool IsAutoSyncEnable { get; set; }

        /// <summary>
        /// Allows to get and set the frequency used in the atosync.
        /// </summary>
        double AutoSyncFrequency { get; set; }

        /// <summary>
        /// Tell the view to show itself as a dialog.
        /// </summary>
        void ShowDialog();
    }
}
