﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using Canonical.UbuntuOne.Common.Threading;

namespace Canonical.UbuntuOne.Common.Tests
{
    /// <summary>
    /// Dummy implementation of the IDispatcher that is used for test puposes.
    /// </summary>
    internal class TestDispatcher : IDispatcher
    {
        #region Implementation of IDispatcher

        /// <summary>
        /// Dispatches the specified action to the thread.
        /// </summary>
        /// <param name="actionToInvoke">The action to invoke.</param>
        public void Dispatch(Action actionToInvoke)
        {
            actionToInvoke();
        }

        #endregion

        #region Implementation of IDispatcher

        /// <summary>
        /// Dispatches the specified action to the thread.
        /// </summary>
        /// <param name="actionToInvoke">The action to invoke.</param>
        public TResult Dispatch<TResult>(Func<TResult> actionToInvoke)
        {
            return actionToInvoke();
        }

        #endregion

        #region Implementation of IDispatcher

        /// <summary>
        /// Checks whether the thread invoking the method .
        /// </summary>
        /// <returns></returns>
        public bool DispatchRequired()
        {
            return false;
        }

        #endregion
    }
}
