﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using Canonical.UbuntuOne.Common.Threading;
using Canonical.UbuntuOne.Common.Update;
using Microsoft.ApplicationBlocks.Updater;
using NUnit.Framework;
using Rhino.Mocks;
namespace Canonical.UbuntuOne.Common.Tests.Update
{
    [TestFixture]
    public class DownloadingPresenterFixture
    {
        #region Variables

        private MockRepository _mocks;
        private IDownloadingView _view;
        private IDispatcher _dispatcher;
        private DownloadingPresenter _presenter;

        #endregion

        #region SetUp & TearDown

        [SetUp]
        public void Setup()
        {
            _mocks = new MockRepository();
            _view = _mocks.DynamicMock<IDownloadingView>();
            _dispatcher = new TestDispatcher();
            _presenter = new DownloadingPresenter
            {
                View = _view
            };
            // If you do not do this the _view will want to play back the settins done inthe 
            // _presenter set view method.
            _mocks.BackToRecord(_view);
        }

        #endregion

        [Test]
        public void ViewSetterPropertyNullViewTest()
        {
            using(_mocks.Record())
            {
                _view.MaximumValue = DownloadingPresenter.MaximumValue;
                _view.MinimumValue = DownloadingPresenter.MinimumValue;
                _view.Progress = DownloadingPresenter.MinimumValue;

            }
            using(_mocks.Playback())
            {
                _presenter.View = _view;
            }
        }

        [TestCase(34, 45)]
        [TestCase(2, 100)]
        [TestCase(35, 100)]
        public void DownloadProgressHandlerVisibleTest(long progress, long total)
        {
            using (_mocks.Record())
            {
                SetupResult.For(_view.IsShown)
                    .Return(true);
                SetupResult.For(_view.ViewDispatcher)
                    .Return(_dispatcher);

                _view.DownloadingMessage = UpdateResources.DownloadInProgress;
                _view.Progress = (progress * DownloadingPresenter.MaximumValue) / total;
            }
            using (_mocks.Playback())
            {
                _presenter.DownloadProgressHandler(this, new DownloadTaskProgressEventArgs(total, progress, 2, 1, null));
            }
        }

        [TestCase(34, 45)]
        [TestCase(2, 100)]
        [TestCase(35, 100)]
        public void DownloadProgressHandlerNotVisibleTest(long progress, long total)
        {
            using (_mocks.Record())
            {
                SetupResult.For(_view.IsShown)
                    .Return(false);
                Expect.Call(() => _view.Show())
                    .Repeat.Once();
                SetupResult.For(_view.ViewDispatcher)
                    .Return(_dispatcher);
                _view.DownloadingMessage = UpdateResources.DownloadInProgress;
                _view.Progress = (progress * DownloadingPresenter.MaximumValue) / total;
            }
            using (_mocks.Playback())
            {
                _presenter.DownloadProgressHandler(this, new DownloadTaskProgressEventArgs(total, progress, 2, 1, null));
            }
        }

        [Test]
        public void DownloadErrorHandlerTest()
        {
            using (_mocks.Record())
            {
                SetupResult.For(_view.ViewDispatcher)
                    .Return(_dispatcher);
                _view.DownloadingMessage = UpdateResources.DownloadError;
                _view.CloseButtonIsEnabled = true;
                _view.Progress = DownloadingPresenter.MinimumValue;
            }
            using (_mocks.Playback())
            {
                _presenter.DownloadErrorHandler(this, new DownloadTaskErrorEventArgs(null, new Exception()));
            }
        }

        [Test]
        public void DownloadUpdateCompleted()
        {
            using (_mocks.Record())
            {
                SetupResult.For(_view.ViewDispatcher)
                    .Return(_dispatcher);
                _view.DownloadingMessage = UpdateResources.DownloadCompleted;
                _view.Progress = DownloadingPresenter.MaximumValue;
                _view.Close();
            }
            using (_mocks.Playback())
            {
                _presenter.DownloadUpdateCompleted(this, new TaskEventArgs(null));
            }
        }

    }
}
