﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */

using System;
using Canonical.UbuntuOne.Common.Update;
using NUnit.Framework;

namespace Canonical.UbuntuOne.Common.Tests.Update
{
    [TestFixture]
    public class SelfUpdateExceptionFixture
    {

        #region Tests

        [Test]
        public void EmptyConstructor()
        {
            var ex = new SelfUpdateException();
            Assert.IsNotNullOrEmpty(ex.Message);
            Assert.IsNull(ex.InnerException);
        }

        [TestCase("Message")]
        [TestCase("mandel")]
        public void MessageConstructorTest(string message)
        {
            var exception = new SelfUpdateException(message);
            Assert.AreEqual(message, exception.Message);
        }

        [TestCase("Message", typeof(InvalidOperationException))]
        [TestCase("mandel", typeof(NullReferenceException))]
        public void MessageInnerExceptionConstructor(string message, Type exceptionType)
        {
            var inner = (Exception)Activator.CreateInstance(exceptionType);
            var ex = new SelfUpdateException(message, inner);
            Assert.AreEqual(message, ex.Message);
            Assert.IsInstanceOf(exceptionType, ex.InnerException);
        }
        #endregion
    }
}
