﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */

using Canonical.UbuntuOne.Common.Threading;
using Canonical.UbuntuOne.Common.Update;
using NUnit.Framework;
using Rhino.Mocks;

namespace Canonical.UbuntuOne.Common.Tests.Update
{
    [TestFixture]
    public class UpdatingPresenterFixture
    {
        #region Variables

        private MockRepository _mocks;
        private IUpdatingView _view;
        private UpdatingPresenter _presenter;
        private IDispatcher _dispatcher;

        #endregion

        #region Setup & TearDown

        [SetUp]
        public void Setup()
        {
            _mocks = new MockRepository();
            _view = _mocks.StrictMock<IUpdatingView>();
            _dispatcher = _mocks.StrictMock<IDispatcher>();
            _presenter = new UpdatingPresenter
            {
                View = _view
            };
        }

        #endregion

        #region Tests

        [Test]
        public void UpdatingStartedShownTest()
        {
            using(_mocks.Record())
            {
                SetupResult.For(_view.IsShown)
                    .Return(true);
                SetupResult.For(_view.ViewDispatcher)
                    .Return(_dispatcher);
                Expect.Call(() => _dispatcher.Dispatch(null))
                    .IgnoreArguments();
            }
            using(_mocks.Playback())
            {
                _presenter.UpdatingStarted();
            }
        }

        [Test]
        public void UpdatingStartedNotShownTest()
        {
            using (_mocks.Record())
            {
                SetupResult.For(_view.IsShown)
                    .Return(false);
                SetupResult.For(_view.ViewDispatcher)
                    .Return(_dispatcher);
                Expect.Call(() => _dispatcher.Dispatch(null))
                    .IgnoreArguments()
                    .Repeat.Twice();
            }
            using (_mocks.Playback())
            {
                _presenter.UpdatingStarted();
            }
        }

        [Test]
        public void UpdatingFinishedTest()
        {
            using (_mocks.Record())
            {
                SetupResult.For(_view.ViewDispatcher)
                    .Return(_dispatcher);
                Expect.Call(() => _dispatcher.Dispatch(null))
                    .IgnoreArguments();
            }
            using (_mocks.Playback())
            {
                _presenter.UpdatingFinished();
            }
        }

        #endregion

    }
}
