﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.Reflection;
using log4net;
using Spring.Aop;

namespace Canonical.UbuntuOne.Common.Aop
{
    /// <summary>
    /// This interceptor provides a nice way to wrap the call of the different methods in the classes
    /// and provide extra logging that is useful when debugging. The interceptor will wrap the method calls
    /// and will add a post-call logging.
    /// </summary>
    public class DebugLogAfterCallInterceptor : LoggingInterceptor, IAfterReturningAdvice
    {
        private readonly ILog _logger = LogManager.GetLogger(typeof (DebugLogAfterCallInterceptor));

        /// <summary>
        /// Callback after a given method successfully returned.
        /// </summary>
        /// <param name="returnValue">The value returned by the method, if any</param>
        /// <param name="method">Method being invoked</param>
        /// <param name="args">Arguments to the method</param>
        /// <param name="target">Target of the method invocation. May be null.</param>
        public void AfterReturning(object returnValue, MethodInfo method, object[] args, object target)
        {
            if(Logger == null)
                Logger = GetLogger(target);
            if(Logger != null)
            {
                if(returnValue != null)
                {
                    Logger.DebugFormat("< {0}()", method.Name);
                }
                else
                {
                    Logger.DebugFormat("< {0}(result: {1})", method.Name, returnValue);
                }
            }
            else
            {
                _logger.WarnFormat(AopResources.LoggerNotSet, method.Name);
            }
        }
    }
}
