﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.Reflection;
using log4net;
using Spring.Aop;

namespace Canonical.UbuntuOne.Common.Aop
{
    /// <summary>
    /// This interceptor provides a nice way to wrap the call of the different methods in the classes
    /// and provide extra logging that is useful when debugging. The interceptor will wrap the method calls
    /// and will add a logging call after an expcetion has been thrown.
    /// </summary>
    public class DebugLogAfterThrowInterceptor : LoggingInterceptor, IThrowsAdvice
    {
        private readonly ILog _logger = LogManager.GetLogger(typeof (DebugLogAfterThrowInterceptor));

        /// <summary>
        /// Method that will be executed after an exception has been thrown by the method to which
        /// the advice was added.
        /// </summary>
        /// <param name="method">The method that threw the exception.</param>
        /// <param name="args">The arguments which were used to call the method.</param>
        /// <param name="target">The object that is target of the method.</param>
        /// <param name="ex">The exception thrown by the method execution.</param>
        public void AfterThrowing(MethodInfo method, object[] args, object target, Exception ex)
        {
            if(Logger == null)
                Logger = GetLogger(target);
            if(Logger != null)
            {
                
                Logger.WarnFormat("{0} thrown when calling {1}", ex, args == null || args.Length == 0 ? 
                    LogNoArguments(method) : LogArguments(method, args));
            }
            else
            {
                _logger.WarnFormat(AopResources.LoggerNotSet, method.Name);
            }
        }
    }
}
