﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;

namespace Canonical.UbuntuOne.Common.Net
{
    /// <summary>
    /// Simple interface to be implemented by those objects that are able to create web requests.
    /// </summary>
    public interface IHttpWebRequestFactory
    {
        /// <summary>
        /// Creates a new webrequest that will be used to request an internet resource that is identified
        /// by the given uri.
        /// </summary>
        /// <param name="uri">A string with the uri that identifies the internet resource.</param>
        /// <returns>An IHttpWebRequest that can be used to request an internet resource.</returns>
        IHttpWebRequest Create(string uri);

        /// <summary>
        /// Creates a webrequest that will be used to request an internet resource that is identified by
        /// the given uri.
        /// </summary>
        /// <param name="uri">An object that identifies the web request.</param>
        /// <returns>An HttpWebRequest that can be used to request an internet resource.</returns>
        IHttpWebRequest Create(Uri uri);
    }
}
