﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.ServiceModel;

namespace Canonical.UbuntuOne.Common.Net
{
    /// <summary>
    /// Interface to be implemented by those objects that allow to call WCF service and that will
    /// perform all the house keeping required.
    /// </summary>
    public interface IServiceCaller
    {
        /// <summary>
        /// A method that allows to correctly clean a channel when executing a call to
        /// a web service. This method takes an action that should be using the channel
        /// and the casted channel so that we can access the ICommunicationObject methods.
        /// </summary>
        /// <param name="action">The action to be performed that uses the channel.</param>
        /// <param name="channel">The casted channel that will be used to clean its state.</param>
        void SaveProxyCall(Action action, ICommunicationObject channel);

        /// <summary>
        /// A method that allows to correctly clean a channel when executing a call to
        /// a web service. This method takes an action that should be using the channel
        /// and the casted channel so that we can access the ICommunicationObject methods.
        /// </summary>
        /// <param name="action">An action that has a wcf proxy call.</param>
        /// <param name="channel">The casted channel that will be used to clean its state.</param>
        /// <returns>The result of the action</returns>
        TResult SaveProxyCall<TResult>(Func<TResult> action, ICommunicationObject channel);
    }
}
