﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.ServiceModel;

namespace Canonical.UbuntuOne.Common.OperationContracts
{
    /// <summary>
    /// Interface to be implemented by those objects that will allow to 
    /// </summary>
    [ServiceContract( CallbackContract = typeof(ISyncDaemonClient),
        SessionMode = SessionMode.Required)]
    public interface IEventNotifier
    {
        /// <summary>
        /// Method that allows to register a client that will be reciving notitications 
        /// from than point until it unregisters
        /// </summary>
        [OperationContract(IsOneWay = true)]
        void RegisterClient();

        /// <summary>
        /// Method that allows to unregister a client from receiving notification.
        /// </summary>
        [OperationContract(IsOneWay = true)]
        void UnregisterClient();

        /// <summary>
        /// Method that tells the notifier to start listening for other events using a separate thread.
        /// </summary>
        void StartListening();

        /// <summary>
        /// Method that tells the notifier to stop listning for events.
        /// </summary>
        void StopListening();

        /// <summary>
        /// Gets if the notifier is listening.
        /// </summary>
        bool IsListening { get; }

    }
}
