﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using DotUpdater;
using Microsoft.ApplicationBlocks.Updater;

namespace Canonical.UbuntuOne.Common.Update
{
    internal class DotUpdaterWrapper : IDotUpdaterWrapper
    {
        #region Events

        public event EventHandler<TaskEventArgs> OnDownloadCompleted;
        public event EventHandler<DownloadTaskProgressEventArgs> OnDownloadProgress;
        public event EventHandler<DownloadTaskErrorEventArgs> OnDownloadError;

        #endregion

        #region Variables

        private DotUpdater.Updater _updater;

        #endregion

        #region Helpers

        /// <summary>
        /// Helper used to propagate the event from the wrapped object.
        /// </summary>
        /// <param name="sender">The sender of the event.</param>
        /// <param name="args">The aruments about the completed task.</param>
        private void DownloadCompletedHandler(object sender, TaskEventArgs args)
        {
            if(OnDownloadCompleted != null)
            {
                OnDownloadCompleted(sender, args);
            }
        }

        /// <summary>
        /// Helper used to propagate the event from the wrapped object.
        /// </summary>
        /// <param name="sender">The sender of the event.</param>
        /// <param name="args">The arguments with the completed information.</param>
        private void DownloadProgressHandler(object sender, DownloadTaskProgressEventArgs args)
        {
            if(OnDownloadProgress != null)
            {
                OnDownloadProgress(sender, args);
            }
        }

        /// <summary>
        /// Helper used to propagate the event from the wrapped object.
        /// </summary>
        /// <param name="sender">The sender of the event.</param>
        /// <param name="args">The arguments with the error information.</param>
        private void DownloadErrorHandler(object sender, DownloadTaskErrorEventArgs args)
        {
            if(OnDownloadError != null)
            {
                OnDownloadError(sender, args);
            }
        }

        #endregion

        public DotUpdaterWrapper(Logger logger, string rss)
        {
            _updater = new DotUpdater.Updater(logger, rss);
            _updater.OnDownloadCompleted += DownloadCompletedHandler;
            _updater.OnDownloadProgress += DownloadProgressHandler;
            _updater.OnDownloadError += DownloadErrorHandler;
        }

        public UpdaterTask CheckForUpdates()
        {
            return _updater.CheckForUpdates();
        }

        public void Install(UpdaterTask task)
        {
            _updater.Install(task);
        }

        public void BeginDownload(UpdaterTask task)
        {
            _updater.BeginDownload(task);
        }

        public void Dispose()
        {
            _updater.Dispose();
        }
    }
}
