﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */

using Canonical.UbuntuOne.Common.Threading;

namespace Canonical.UbuntuOne.Common.Update
{
    /// <summary>
    /// Interface to be implemented by those views that will interact with the user when 
    /// the application is being updated.
    /// </summary>
    public interface IUpdatingView
    {
        /// <summary>
        /// Gets the dispatcher that can be used to call actions on the object from a 
        /// different thread.
        /// </summary>
        IDispatcher ViewDispatcher { get; }

        /// <summary>
        /// Gets and sets if the view is visible
        /// </summary>
        bool IsShown { get; }

        /// <summary>
        /// Gets and sets if the application is being updated.
        /// </summary>
        bool IsUpdating { get; set; }

        /// <summary>
        /// Gets and sets the text tht tell the user the app is being updated.
        /// </summary>
        string UpdatingText { get; set; }

        /// <summary>
        /// Displays the view to the user.
        /// </summary>
        void Show();

        /// <summary>
        /// Closes the view.
        /// </summary>
        void Close();
    }
}
