﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */

namespace Canonical.UbuntuOne.Common.Update
{
    /// <summary>
    /// Implementation of the IUpdatingPresenter that manages the UI used to communicate the 
    /// user that an update is taking place.
    /// </summary>
    public class UpdatingPresenter : IUpdatingPresenter
    {
        /// <summary>
        /// Gets and sets the view that is used to interact with the user.
        /// </summary>
        public IUpdatingView View { get; set; }

        /// <summary>
        /// Method used to notify the user that the updating started.
        /// </summary>
        public void UpdatingStarted()
        {
            if (!View.IsShown)
                View.ViewDispatcher.Dispatch(() => View.Show());
            View.ViewDispatcher.Dispatch(
                () =>
                    {
                        View.UpdatingText = UpdateResources.UpdateStarted;
                        View.IsUpdating = true;
                    });
            
        }

        /// <summary>
        /// Method used to notify the user that the updating finished.
        /// </summary>
        public void UpdatingFinished()
        {
            View.ViewDispatcher.Dispatch(
                () =>
                    {
                        View.UpdatingText = UpdateResources.UpdateFinished;
                        View.IsUpdating = false;
                    });
        }
    }
}
