﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.Collections.Generic;
using System.Windows;

namespace Canonical.UbuntuOne.Common.Utils
{
    /// <summary>
    /// Interface that allows to abstract an application in C# allowing to make the code more testable.
    /// </summary>
    public interface IApplication
    {
        /// <summary>
        /// Gets and sets the tasks that will be executed in sequencial 
        /// order during the start up of the application.
        /// </summary>
        IList<IStartupTask> StartupTasks { get; set; }
 
        /// <summary>
        /// Allows to start the application using the passed window.
        /// </summary>
        /// <param name="startWindow">The main window of the application.</param>
        void Run(Window startWindow);

        /// <summary>
        /// Gets and sets the shutdown mode to be used in the application.
        /// </summary>
        ShutdownMode ShutdownMode { get; set; }

        /// <summary>
        /// Allows to close the application.
        /// </summary>
        void Exit();
    }
}
