﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.Collections.Generic;

namespace Canonical.UbuntuOne.Common.Utils
{
    /// <summary>
    /// Interface to be implemented by those object that know how to locate an application in the system so that
    /// it can be called in a different process.
    /// </summary>
    public interface IApplicationLocator
    {
        /// <summary>
        /// Returns a collecion with the names of the known application by the object.
        /// </summary>
        /// <returns>A string with all the different applications that the object knows how to locate.</returns>
        ICollection<string> GetKnownApplications();

        /// <summary>
        /// Returns the full path in the system of the application that mathces the given name.
        /// </summary>
        /// <param name="appName">The name of the application we want to locate.</param>
        /// <returns>The full path of the application with the given name.</returns>
        string GetApplicationPath(string appName);

    }
}
