namespace Canonical.UbuntuOne.ProcessDispatcher
{
    internal interface IPipeListener
    {
        /// <summary>
        /// Gets if the pipe listener is indeed listening to the pipe.
        /// </summary>
        bool IsListening { get; }

        /// <summary>
        /// Gets and sets the number of threads that will be used to listen to the 
        /// pipe. Each thread will listeng to connections and will dispatch the 
        /// messages when ever they are done.
        /// </summary>
        int NumberOfThreads { get; set; }

        /// <summary>
        /// Gets and sets the pipe stream factory that know how to generate the streamers used for the communication.
        /// </summary>
        IPipeStreamerFactory PipeStreamerFactory { get; set; }

        /// <summary>
        /// Gets and sets the action that will be performed with the message of that 
        /// is received by the pipe listener.
        /// </summary>
        IMessageProcessor MessageProcessor { get; set; }

        /// <summary>
        /// Starts listening to the different pipe messages and will perform the appropiate
        /// action when a message is received.
        /// </summary>
        /// <param name="namedPipe">The name fof the pipe to listen.</param>
        void StartListening(string namedPipe);

        /// <summary>
        /// Stops listening to the different pipe messages. All the thread that are listening already will 
        /// be forced to stop.
        /// </summary>
        void StopListening();
    }
}