﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.IO;
using System.Text;

namespace Canonical.UbuntuOne.ProcessDispatcher
{
    /// <summary>
    /// Interface that should be implemented by those objects that
    /// know the protocol that is used to communicate with the python code.
    /// </summary>
    public interface IPipeStreamer
    {
        /// <summary>
        /// Gets and sets the encoding used by the streamer.
        /// </summary>
        Encoding Encoding { get; set; }

        /// <summary>
        /// Reads the current contents that are present in the stream and returns an object that
        /// represents them.
        /// </summary>
        /// <param name="stream">The stream from which the data is read.</param>
        /// <returns>An object that represents the data in the stream.</returns>
        object Read(Stream stream);

        /// <summary>
        /// Writes the given object to the stream so that the python code can read it.
        /// </summary>
        /// <param name="outData">The object to be serialized in the stream.</param>
        /// <param name="stream">The stream to which the serialization will be written.</param>
        /// <returns>The position in the stream after the write operation.</returns>
        int Write(object outData, Stream stream);
    }
}
