﻿/*
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using Canonical.UbuntuOne.Client.Notification;
using Newtonsoft.Json.Linq;

namespace Canonical.UbuntuOne.ProcessDispatcher
{
    /// <summary>
    /// Message processor that works with json messages from python.
    /// </summary>
    internal class JsonMessageProcessor : IMessageProcessor
    {
        #region DI Properties

        /// <summary>
        /// Gets and sets the notification view that will be used to send messages to the user.
        /// </summary>
        public INotificationIconView NotificationIconView { get; set; } 

        #endregion

        /// <summary>
        /// Will process the message sent by the python code and will perform all the possibly required operations.
        /// </summary>
        /// <param name="message"></param>
        public void ProcessMessage(object message)
        {
            // a message is a string that will be parsed from json and its value interpretated.
            var messageObject = (JObject) message;
            if(string.Compare((string)messageObject["type"], "notify", StringComparison.CurrentCultureIgnoreCase) == 0)
            {
                NotificationIconView.ShowNotification(10, (string)messageObject["title"], (string)messageObject["message"]);
            }
        }
    }
}
