﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using Canonical.UbuntuOne.Common.Container;
using Canonical.UbuntuOne.Common.Update;
using NUnit.Framework;

namespace UbuntuOneClient.Tests
{
    /// <summary>
    /// Intergation test class that test that the configuration of the client app has been correctly done.
    /// </summary>
    [TestFixture]
    public class ConfigurationFixture
    {
        #region Tests

        [Test]
        public void ProgramIsNotNullTest()
        {
            Assert.IsNotNull(ObjectsContainer.GetImplementationOf<Program>());
        }

        [Test]
        public void UpdaterIsNotNull()
        {
            var program = ObjectsContainer.GetImplementationOf<Program>();
            Assert.IsNotNull(program.Updater);
        }

        [Test]
        public void NotifyIconIsNotNull()
        {
            var program = ObjectsContainer.GetImplementationOf<Program>();
            Assert.IsNotNull(program.NotifyIcon);
        }

        [Test]
        public void ApplicationIsNotNull()
        {
            var program = ObjectsContainer.GetImplementationOf<Program>();
            Assert.IsNotNull(program.Application);
        }

        [Test]
        public void DownloadingPresenterIsNotNull()
        {
            var program = ObjectsContainer.GetImplementationOf<Program>();
            var updater = program.Updater as Updater;
            if(updater != null)
            {
                Assert.IsNotNull(updater.DownloadingPresenter);
            }
            else
            {
                Assert.Inconclusive("The integration test cannot be ran because the expected inject type was {0}", typeof(Updater));
            }
        }

        [Test]
        public void DownloadingPresenterHasView()
        {
            var program = ObjectsContainer.GetImplementationOf<Program>();
            var updater = program.Updater as Updater;
            if (updater != null)
            {
                var presenter = updater.DownloadingPresenter;
                Assert.IsNotNull(presenter.View);
            }
            else
            {
                Assert.Inconclusive("The integration test cannot be ran because the expected inject type was {0}", typeof(Updater));
            }
        }

        [Test]
        public void UpdatingPresenterIsNotNull()
        {
            var program = ObjectsContainer.GetImplementationOf<Program>();
            var updater = program.Updater as Updater;
            if (updater != null)
            {
                Assert.IsNotNull(updater.UpdatingPresenter);
            }
            else
            {
                Assert.Inconclusive("The integration test cannot be ran because the expected inject type was {0}", typeof(Updater));
            }
        }

        [Test]
        public void UpdatingPresetnerHasView()
        {
            var program = ObjectsContainer.GetImplementationOf<Program>();
            var updater = program.Updater as Updater;
            if (updater != null)
            {
                var presenter = updater.UpdatingPresenter;
                Assert.IsNotNull(presenter.View);
            }
            else
            {
                Assert.Inconclusive("The integration test cannot be ran because the expected inject type was {0}", typeof(Updater));
            }
        }


        #endregion
    }
}
