# Ubuntu One windows Ion overlays
#
# Author: Tim Cole <tim.cole@canonical.com>
#
# Copyright 2009 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
import os
from win32com.shell import shell, shellcon
import winerror
import _winreg
import win32api
import win32con
import win32com.server.register
from u1sync import metadata
from u1sync.constants import METADATA_DIR_NAME

def get_icon_root_location():
    # First open the registry hive
    hive = _winreg.ConnectRegistry(None, _winreg.HKEY_LOCAL_MACHINE)
    key = _winreg.OpenKey(hive, "Software\Canonical\UbuntuOne")
    for i in range(0, _winreg.QueryInfoKey(key)[1]):
        name, value, val_type = _winreg.EnumValue(key, i)
        # Common AppData will always be present unless the user played with regedit
        if name == "InstallationPath":
            return os.path.join(value, "icons")
    
def file_is_in_ubuntuone_root(path):
    absolute_path = os.path.abspath(path)
    while True:
        metadir = os.path.join(absolute_path, '.ubuntuone-sync')
        if os.path.exists(metadir):
            return True
        if absolute_path == "C:\\":
            return False
        absolute_path = os.path.split(absolute_path)[0]
    return True
    
def get_metadata_dir(path):
    # we need to find the metadata
    absolute_path = os.path.abspath(path)
    while True:
        metadir = os.path.join(absolute_path, '.ubuntuone-sync')
        if os.path.exists(metadir):
            return metadir
        if absolute_path == "C:\\":
            None
        absolute_path = os.path.split(absolute_path)[0]
    return None
    
def file_was_modified(path):
    absolute_path = os.path.abspath(path)
    metadir = get_metadata_dir(path)
    modified_files = open(os.path.join(metadir, "modified.data"), "rb")
    modified_data = modified_files.read()
    index = modified_data.find(absolute_path)
    return index >= 0
    
class ModifiedIconOverlay:
    _reg_clsid_ = '{9c2b3e80-d766-11df-937b-0800200c9a66}'
    _reg_progid_ = 'TJG.PythonPackagesOverlayHandler'
    _reg_desc_ = 'Icon Overlay Handler to indicate Python packages'
    _public_methods_ = ['GetOverlayInfo', 'GetPriority', 'IsMemberOf']
    _com_interfaces_ = [shell.IID_IShellIconOverlayIdentifier]
  
    def GetOverlayInfo(self):
        icon_path = os.path.join(get_icon_root_location(), "conflict.ico")
        return (icon_path, 0, shellcon.ISIOI_ICONFILE)
  
    def GetPriority(self):
        return 50
  
    def IsMemberOf(self, fname, attributes):
        if file_is_in_ubuntuone_root(fname) and file_was_modified(fname):
            return winerror.S_OK
        return winerror.E_FAIL
    
class AddedIconOverlay:
    _reg_clsid_ = '{a9a25b70-d766-11df-937b-0800200c9a66}'
    _reg_progid_ = 'TJG.PythonPackagesOverlayHandler'
    _reg_desc_ = 'Icon Overlay Handler to indicate Python packages'
    _public_methods_ = ['GetOverlayInfo', 'GetPriority', 'IsMemberOf']
    _com_interfaces_ = [shell.IID_IShellIconOverlayIdentifier]
  
    def GetOverlayInfo(self):
        icon_path = os.path.join(get_icon_root_location(), "added.ico")
        return (icon_path, 0, shellcon.ISIOI_ICONFILE)
  
    def GetPriority(self):
        return 50
  
    def IsMemberOf(self, fname, attributes):
        if file_is_in_ubuntuone_root(fname):
            return winerror.S_OK
        return winerror.E_FAIL

def icon_overlays_are_registered():
    # First open the registry hive
    hive = _winreg.ConnectRegistry(None, _winreg.HKEY_LOCAL_MACHINE)
    # Then open the registry key where we stored the overlays
    try:
        key = _winreg.OpenKey(hive, "Software\Microsoft\Windows\CurrentVersion\Explorer\ShellIconOverlayIdentifiers\UbuntuOneModifiedIconOverlay")
        key = _winreg.OpenKey(hive, "Software\Microsoft\Windows\CurrentVersion\Explorer\ShellIconOverlayIdentifiers\UbuntuOneAddedIconOverlay")
        return True
    except:
        return False
        
def register_icon_overlays():
    win32com.server.register.UseCommandLine (ModifiedIconOverlay)
    win32com.server.register.UseCommandLine (AddedIconOverlay)
 