# ubuntuone.u1sync.utils
#
# Miscellaneous utility functions
#
# Author: Tim Cole <tim.cole@canonical.com>
#
# Copyright 2009 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Miscellaneous utility functions."""

import json
import os
import getpass

import win32pipe
from errno import EEXIST, ENOENT
from u1sync.constants import (
    METADATA_DIR_NAME, SPECIAL_FILE_RE)

def should_sync(filename):
    """Returns True if the filename should be synced.

    @param filename: a unicode filename

    """
    return filename != METADATA_DIR_NAME and \
           not SPECIAL_FILE_RE.match(filename)

def safe_mkdir(path):
    """Creates a directory iff it does not already exist."""
    try:
        os.mkdir(path)
    except OSError, e:
        if e.errno != EEXIST:
            raise

def safe_unlink(path):
    """Unlinks a file iff it exists."""
    try:
        os.unlink(path)
    except OSError, e:
        if e.errno != ENOENT:
            raise

def get_user():
    """Return the name of the current user."""
    return r'{0}\{1}'.format(os.getenv('COMPUTERNAME'), getpass.getuser())
    
def create_error_message(error_message, exception):
    """Create a new error message"""
    # hack, I really dislike this, later using protobuf we 
    # can state the type of error, right now, this should do the work.
    message = {'type':'error', 
               'message':error_message, 
               'expcetion':type(exception.__class__.__name__)}
    return message
    
def send_bus_message(message):
    """Sends a message to a pipe listen by an other lang."""
    pipe_name = r'\\.\pipe\PythonMessages{0}'.format(get_user())
    # calulate json representation of the message 
    data_json = json.dumps(message)
    length = str(len(data_json)/256)
    length += str(len(data_json)&256)
    data_json = length + data_json
    # call the pipe with the message
    try:
        data = win32pipe.CallNamedPipe(pipe_name, 
            data_json, len(data_json), 0 )
    except Exception, e:
        print "Error: C# client is not listening!! %s" % e.message
    
def send_bus_error(error_message, exception):
    message = create_error_message(error_message, exception)
    send_bus_message(message)
    
def send_notification(title, message, type):
    message = {'type':'notify',
                'title':title,
                'message':message,
                'notification_type':type}
    send_bus_message(message)
    