#!/usr/bin/python
# Copyright 2010 Canonical Ltd.  All rights reserved.

"""This utilities release an Ubuntu One windows update."""

import hashlib
import os
import sys
import time
from uuid import uuid1

import boto
from boto.s3.key import Key
from boto.exception import S3ResponseError

from rss_templates import RSS_TEMPLATE



BUCKET = 'u1wintest'
RSS_FILE_NAME = 'rss'


def upload_package(bucket, filename, rss_params):
    """Upload the package"""
    k = Key(bucket)
    path = filename.split('\\')
    name = path[len(path) -1]
    keyname = rss_params['version'] + '/' + name
    k.key = keyname
    print 'Uploading %s...' % name
    k.set_contents_from_filename(filename)
    bucket.set_acl('public-read', keyname)
    print "Uploaded!"


def upload_rss(bucket, filename, rss_params):
    """Upload the RSS"""
    now = time.strftime('%d %b %Y %H:%M:%S %Z')
    rss_params['lastBuildDate'] = rss_params['pubDate'] = now
    fd = open(filename,'rb')
    md5_hash = hashlib.md5(fd.read()).hexdigest()
    rss_params['md5'] = md5_hash
    rss_params['lenght'] = os.path.getsize(filename)
    rss_params['url'] = rss_params['url']
    try:
        print 'Removing rss...'
        bucket.delete_key(RSS_FILE_NAME)
    except S3ResponseError:
        print 'No previous upload'
    print 'Generating new rss...'
    rss = RSS_TEMPLATE.substitute(rss_params)
    print 'Uploading new rss...'
    k = Key(bucket)
    k.key = RSS_FILE_NAME
    k.set_contents_from_string(rss)
    bucket.set_acl('public-read', RSS_FILE_NAME)
    print "Uploaded!"


def main(filename, rss_params):
    """ """
    # connect to S3
    print 'Connecting to S3...'
    conn = boto.connect_s3()
    print 'Connected!'
    bucket = conn.get_bucket(BUCKET)
    upload_package(bucket, filename, rss_params)
    upload_rss(bucket, filename, rss_params)


if __name__ == '__main__':
    argv = sys.argv
    #FIXME check we have AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY in the env
    if len (argv) != 4:
        print "Usage: upload_new_update.py package_file version url"
        print "example:"
        print 'python upload_new_update.py u1client.msi 0.0.2 "/u1wintest"'
        sys.exit()
    package_filename = argv[1]
    rss_params = {}
    rss_params['version'] =  argv[2]
    rss_params['url'] = argv[3]
    rss_params['uuid'] = str(uuid1())
    sys.exit(main(filename=argv[1], rss_params=rss_params))
